import * as mongodb from 'mongodb';
import { getMongoDbPromise } from './get-mongo-db';
import { isMongoDefinition } from './helpers/is-mongo-definition';
import { IMongoAppenderConfiguration } from './types/types';

/**
 * @description Init mongodb collection
 *
 * @export
 * @param {(mongodb.Collection | undefined)} dbCollection saved connection
 * @param {IMongoAppenderConfiguration} config Configuration to mongo
 * @param {((err: Error | undefined, resp: mongodb.Collection | undefined) => void)} cb
 */
/*
function getMongoCollection(
    dbCollection: mongodb.Collection | undefined,
    config: IMongoAppenderConfiguration,
    cb: (err: Error | undefined, resp: mongodb.Collection | undefined) => void,
): void {
    if (dbCollection) {
        cb(undefined, dbCollection);
    } else if (config) {
        if (isMongoDefinition(config.mongoSetting)) {
            getMongoDb(config.mongoSetting, (err, collection) => {
                if (err || !collection) {
                    cb(err, undefined);
                } else {
                    cb(undefined, collection);
                }
            });
        } else {
            const result: mongodb.Collection = config.mongoSetting.client
                .db(config.mongoSetting.database)
                .collection(config.mongoSetting.collection);
            cb(undefined, result);
        }
    } else {
        cb(new Error('No config or collection is defined!'), undefined);
    }
}
*/
/**
 * @description Init mongodb collection
 *
 * @export
 * @param {(mongodb.Collection | undefined)} dbCollection Saved connection
 * @param {IMongoAppenderConfiguration} config Configuration to mongo
 * @return {*}  {Promise<mongodb.Collection>}
 */
export async function getMongoCollection(dbCollection: mongodb.Collection | undefined,
    config: IMongoAppenderConfiguration) : Promise<mongodb.Collection> {
        if (dbCollection) {
            return dbCollection;
        } else if (config) {
            if (isMongoDefinition(config.mongoSetting)) {
                const db = await getMongoDbPromise(config.mongoSetting);
                return db;
            } else {
                const result: mongodb.Collection = config.mongoSetting.client
                .db(config.mongoSetting.database)
                .collection(config.mongoSetting.collection);
                return result;
            }
        } else {
            throw new Error('No config or collection is defined!');
        }
    }